require 'spec_helper'
require 'socket'

describe Quietus::PassiveServer do
  context "creating" do

    context "passed a falsy block" do
      it "refuses a TCP connection" do
        pid = fork do
          Signal.trap("HUP") { exit }
          Quietus::PassiveServer.new { false }
        end

        sleep 1

        expect { TCPSocket.new('localhost', 2347) }.to raise_error(Errno::ECONNREFUSED)

        Process.kill("HUP", pid)
        Process.wait
      end
    end

    context "passed a truthy block" do
      it "allows a TCP connection" do
        pid = fork do
          Signal.trap("HUP") { exit }
          Quietus::PassiveServer.new { true }
        end

        sleep 1

        expect { TCPSocket.new('localhost', 2347) }.not_to raise_error

        Process.kill("HUP", pid)
        Process.wait
      end
    end

  end
end

